# Copyright 2019 Dirk Thomas
# Licensed under the Apache License, Version 2.0

__version__ = '0.1.1'


class NonFunctionalExtensionPoint:
    """Non-functional extension point to list the package in version-check."""

    pass
